@@ -1,9 +1,10 @@
-import tempfile
-import re
 import datetime as dt
-from pandas.io.common import ZipFile
-from pandas.compat import lmap, StringIO
+import re
+import tempfile
+from zipfile import ZipFile
+
 from pandas import read_csv, to_datetime
+from pandas.compat import lmap, StringIO
 
 from pandas_datareader.base import _BaseReader
 
@@ -19,7 +20,7 @@ def get_available_datasets(**kwargs):
     Parameters
     ----------
     session : Session, default None
-            requests.sessions.Session instance to be used
+        requests.sessions.Session instance to be used
 
     Returns
     -------
@@ -32,27 +33,22 @@ def _parse_date_famafrench(x):
     x = x.strip()
     try:
         return dt.datetime.strptime(x, '%Y%m')
-    except:
+    except Exception:
         pass
     return to_datetime(x)
 
 
 class FamaFrenchReader(_BaseReader):
-
     """
     Get data for the given name from the Fama/French data library.
 
     For annual and monthly data, index is a pandas.PeriodIndex, otherwise
     it's a pandas.DatetimeIndex.
-
-    Returns
-    -------
-    df : a dictionary of pandas.DataFrame. Tables are accessed by integer keys.
-         See df['DESCR'] for a description of the dataset
     """
 
     @property
     def url(self):
+        """API URL"""
         return ''.join([_URL, _URL_PREFIX, self.symbols, _URL_SUFFIX])
 
     def _read_zipfile(self, url):
@@ -66,6 +62,18 @@ class FamaFrenchReader(_BaseReader):
 
         return data
 
+    def read(self):
+        """
+        Read data
+
+        Returns
+        -------
+        df : dict
+            A dictionary of DataFrames. Tables are accessed by integer keys.
+            See df['DESCR'] for a description of the data set.
+        """
+        return super(FamaFrenchReader, self).read()
+
     def _read_one_data(self, url, params):
 
         params = {'index_col': 0,
@@ -106,7 +114,7 @@ class FamaFrenchReader(_BaseReader):
                 idx_name = df.index.name  # hack for pandas 0.16.2
                 df = df.to_period(df.index.inferred_freq[:1])
                 df.index.name = idx_name
-            except:
+            except Exception:
                 pass
             df = df.truncate(self.start, self.end)
             datasets[i] = df
@@ -115,10 +123,12 @@ class FamaFrenchReader(_BaseReader):
             shape = '({0} rows x {1} cols)'.format(*df.shape)
             table_desc.append('{0} {1}'.format(title, shape).strip())
 
-        descr = '{0}\n{1}\n\n'.format(self.symbols.replace('_', ' '), len(self.symbols) * '-')
+        descr = '{0}\n{1}\n\n'.format(self.symbols.replace('_', ' '),
+                                      len(self.symbols) * '-')
         if doc_chunks:
             descr += ' '.join(doc_chunks).replace(2 * ' ', ' ') + '\n\n'
-        table_descr = map(lambda x: '{0:3} : {1}'.format(*x), enumerate(table_desc))
+        table_descr = map(lambda x: '{0:3} : {1}'.format(*x),
+                          enumerate(table_desc))
         datasets['DESCR'] = descr + '\n'.join(table_descr)
 
         return datasets
@@ -126,9 +136,11 @@ class FamaFrenchReader(_BaseReader):
     def get_available_datasets(self):
         """
         Get the list of datasets available from the Fama/French data library.
+
         Returns
         -------
-        A list of valid inputs for get_data_famafrench.
+        datasets: list
+            A list of valid inputs for get_data_famafrench
         """
         try:
             from lxml.html import document_fromstring
@@ -139,7 +151,9 @@ class FamaFrenchReader(_BaseReader):
         response = self.session.get(_URL + 'data_library.html')
         root = document_fromstring(response.content)
 
-        l = filter(lambda x: x.startswith(_URL_PREFIX) and x.endswith(_URL_SUFFIX),
-                   [e.attrib['href'] for e in root.findall('.//a') if 'href' in e.attrib])
+        datasets = [e.attrib['href'] for e in root.findall('.//a')
+                    if 'href' in e.attrib]
+        datasets = [ds for ds in datasets if ds.startswith(_URL_PREFIX)
+                    and ds.endswith(_URL_SUFFIX)]
 
-        return lmap(lambda x: x[len(_URL_PREFIX):-len(_URL_SUFFIX)], l)
+        return lmap(lambda x: x[len(_URL_PREFIX):-len(_URL_SUFFIX)], datasets)
