@@ -1,17 +1,14 @@
 from pandas_datareader.base import _DailyBaseReader
-from pandas_datareader.exceptions import UnstableAPIWarning
-
-UNSTABLE_WARNING = """
-The Google Finance API has not been stable since late 2017. Requests seem
-to fail at random. Failure is especially common when bulk downloading.
-"""
+from pandas_datareader.exceptions import ImmediateDeprecationError, \
+    DEP_ERROR_MSG
 
 
 class GoogleDailyReader(_DailyBaseReader):
     """
-    Returns DataFrame/Panel of historical stock prices from symbols, over date
-    range, start to end. To avoid being penalized by Google Finance servers,
-    pauses between downloading 'chunks' of symbols can be specified.
+    Returns DataFrame of historical stock prices from
+    symbols, over date range, start to end. To avoid being penalized by Google
+    Finance servers, pauses between downloading 'chunks' of symbols can be
+    specified.
 
     Parameters
     ----------
@@ -35,9 +32,8 @@ class GoogleDailyReader(_DailyBaseReader):
     """
 
     def __init__(self, symbols=None, start=None, end=None, retry_count=3,
-                 pause=0.001, session=None, chunksize=25):
-        import warnings
-        warnings.warn(UNSTABLE_WARNING, UnstableAPIWarning)
+                 pause=0.1, session=None, chunksize=25):
+        raise ImmediateDeprecationError(DEP_ERROR_MSG.format('Google finance'))
         super(GoogleDailyReader, self).__init__(symbols, start, end,
                                                 retry_count, pause, session,
                                                 chunksize)
@@ -45,7 +41,8 @@ class GoogleDailyReader(_DailyBaseReader):
     @property
     def url(self):
         """API URL"""
-        return 'https://finance.google.com/finance/historical'
+        # Thanks user:vnmabus for pointing this out.
+        return 'https://finance.google.co.uk/bctzjpnsun/historical'
 
     def _get_params(self, symbol):
         params = {
