@@ -15,7 +15,11 @@ import warnings
 import pandas.util.testing as tm
 from pandas.util.testing import assert_series_equal
 
+pytestmark = pytest.mark.filterwarnings(
+    'ignore::pandas_datareader.exceptions.UnstableAPIWarning')
 
+
+@pytest.mark.xfail(reason="Deprecated")
 def assert_n_failed_equals_n_null_columns(wngs, obj, cls=SymbolWarning):
     all_nan_cols_dict = {}
 
@@ -40,6 +44,7 @@ def assert_n_failed_equals_n_null_columns(wngs, obj, cls=SymbolWarning):
     assert msgs.str.contains('|'.join(failed_symbols)).all()
 
 
+@pytest.mark.xfail(reason="Deprecated")
 class TestGoogle(object):
 
     @classmethod
@@ -53,19 +58,20 @@ class TestGoogle(object):
         del cls.locales
 
     def test_google(self):
+
         # asserts that google is minimally working and that it throws
         # an exception when DataReader can't get a 200 response from
         # google
+
         start = datetime(2010, 1, 1)
         end = datetime(2013, 1, 27)
-
         for locale in self.locales:
             with tm.set_locale(locale):
                 panel = web.DataReader("NYSE:F", 'google', start, end)
-            assert panel.Close[-1] == 13.68
+                assert panel.Close[-1] == 13.68
 
-        with pytest.raises(Exception):
-            web.DataReader('NON EXISTENT TICKER', 'google', start, end)
+            with pytest.raises(Exception):
+                web.DataReader('NON EXISTENT TICKER', 'google', start, end)
 
     def assert_option_result(self, df):
         """
@@ -81,14 +87,12 @@ class TestGoogle(object):
                                         'datetime64[ns]']]
         tm.assert_series_equal(df.dtypes, pd.Series(dtypes, index=exp_columns))
 
-    @pytest.mark.xfail(reason="Google quote api is offline as of Oct 1, 2017")
     def test_get_quote_string(self):
         df = web.get_quote_google('GOOG')
         assert df.loc['GOOG', 'last'] > 0.0
         tm.assert_index_equal(df.index, pd.Index(['GOOG']))
         self.assert_option_result(df)
 
-    @pytest.mark.xfail(reason="Google quote api is offline as of Oct 1, 2017")
     def test_get_quote_stringlist(self):
         df = web.get_quote_google(['GOOG', 'AMZN', 'GOOG'])
         assert_series_equal(df.iloc[0], df.iloc[2])
@@ -96,6 +100,7 @@ class TestGoogle(object):
         self.assert_option_result(df)
 
     def test_get_goog_volume(self):
+
         for locale in self.locales:
             with tm.set_locale(locale):
                 df = web.get_data_google('GOOG').sort_index()
@@ -115,16 +120,14 @@ class TestGoogle(object):
                     pan.Close()
 
     def test_get_multi_invalid(self):
-        with warnings.catch_warnings(record=True):
-            sl = ['AAPL', 'AMZN', 'INVALID']
-            pan = web.get_data_google(sl, '2012')
-            assert 'INVALID' in pan.minor_axis
+        sl = ['AAPL', 'AMZN', 'INVALID']
+        data = web.get_data_google(sl, '2012')
+        assert 'INVALID' in data.columns.levels[1]
 
     def test_get_multi_all_invalid(self):
-        with warnings.catch_warnings(record=True):
-            sl = ['INVALID', 'INVALID2', 'INVALID3']
-            with pytest.raises(RemoteDataError):
-                web.get_data_google(sl, '2012')
+        sl = ['INVALID', 'INVALID2', 'INVALID3']
+        with pytest.raises(RemoteDataError):
+            web.get_data_google(sl, '2012')
 
     def test_get_multi2(self):
         with warnings.catch_warnings(record=True) as w:
@@ -146,9 +149,9 @@ class TestGoogle(object):
     def test_dtypes(self):
         # see gh-3995, gh-8980
         data = web.get_data_google(
-                'NYSE:F',
-                start='JAN-01-10',
-                end='JAN-27-13')
+            'NYSE:F',
+            start='JAN-01-10',
+            end='JAN-27-13')
         assert np.issubdtype(data.Open.dtype, np.number)
         assert np.issubdtype(data.Close.dtype, np.number)
         assert np.issubdtype(data.Low.dtype, np.number)
@@ -157,13 +160,15 @@ class TestGoogle(object):
 
     def test_unicode_date(self):
         # see gh-8967
+
         data = web.get_data_google(
-                'NYSE:F',
-                start='JAN-01-10',
-                end='JAN-27-13')
+            'NYSE:F',
+            start='JAN-01-10',
+            end='JAN-27-13')
         assert data.index.name == 'Date'
 
     def test_google_reader_class(self):
+
         r = GoogleDailyReader('GOOG')
         df = r.read()
         assert df.Volume.loc['JAN-02-2015'] == 1446662
